@@ -1,7 +1,9 @@
 import logging
-import time
 import os
+import time
 
+import configargparse
+from cleargrid.logging.userapp import add_log_file
 from cleargrid.util.subprocess import ProcessManager
 
 FORMAT = (
@@ -9,8 +11,6 @@ FORMAT = (
     "%(threadName)10s[%(levelname)7s]:%(message)s"
 )
 
-logging.basicConfig(level=logging.DEBUG, format=FORMAT)
-
 
 def dead(process):
     if not process.is_alive():
@@ -20,6 +20,20 @@ def dead(process):
 
 
 def start():
+    p = configargparse.get_arg_parser(
+        default_config_files=["/etc/cleargrid", "~/.cleargrid"]
+    )
+    p.add("-c", "--config", is_config_file=True, help="config file path")
+    p.add_argument("--log-level", "-L", default="DEBUG", env_var="LOG_LEVEL")
+    p.add_argument("--log-file", type=str, default=True, env_var="LOG_FILE")
+    args = p.parse_known_args()[0]
+
+    logging.basicConfig(level=getattr(logging, args.log_level.upper()))
+    add_log_file(args.log_file, "abu collector")
+
+    os.environ.setdefault("LOG_LEVEL", args.log_level.upper())
+    os.environ.setdefault("LOG_FILE", str(args.log_file))
+
     logging.debug("starting processes")
 
     processes = (
@@ -45,7 +59,8 @@ def start():
     except Exception:
         logging.exception("Unhandled Exception")
     finally:
-        for p in processes:
-            p.shutdown()
+        while any(p.is_alive() for p in processes):
+            for p in processes:
+                p.shutdown()
 
     logging.info("All processes Exited")
